# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rockset/document.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from rockset import value_pb2 as rockset_dot_value__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x16rockset/document.proto\x12\x07rockset\x1a\x13rockset/value.proto\"I\n\x08\x44ocument\x12\n\n\x02id\x18\x02 \x01(\t\x12\x12\n\nevent_time\x18\x01 \x01(\x03\x12\x1d\n\x05value\x18\x03 \x01(\x0b\x32\x0e.rockset.ValueB\x17\n\x10io.rockset.protoP\x00\xf8\x01\x01\x62\x06proto3')



_DOCUMENT = DESCRIPTOR.message_types_by_name['Document']
Document = _reflection.GeneratedProtocolMessageType('Document', (_message.Message,), {
  'DESCRIPTOR' : _DOCUMENT,
  '__module__' : 'rockset.document_pb2'
  # @@protoc_insertion_point(class_scope:rockset.Document)
  })
_sym_db.RegisterMessage(Document)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\020io.rockset.protoP\000\370\001\001'
  _DOCUMENT._serialized_start=56
  _DOCUMENT._serialized_end=129
# @@protoc_insertion_point(module_scope)
