# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rockset/query_field_path.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1erockset/query_field_path.proto\x12\x07rockset\"\x1a\n\x18\x41llIndexesQueryFieldPath\"\xb1\x01\n\x17QueryFieldPathComponent\x12\x0f\n\x05index\x18\x01 \x01(\x05H\x00\x12\r\n\x03key\x18\x02 \x01(\tH\x00\x12\x38\n\x0b\x61ll_indexes\x18\x03 \x01(\x0b\x32!.rockset.AllIndexesQueryFieldPathH\x00\x12.\n\rspecial_field\x18\x04 \x01(\x0e\x32\x15.rockset.SpecialFieldH\x00\x42\x0c\n\npath_union\"F\n\x0eQueryFieldPath\x12\x34\n\ncomponents\x18\x01 \x03(\x0b\x32 .rockset.QueryFieldPathComponent* \n\x0cSpecialField\x12\x10\n\x0cSFIELD_SCORE\x10\x00\x42\x14\n\x10io.rockset.protoP\x00\x62\x06proto3')

_SPECIALFIELD = DESCRIPTOR.enum_types_by_name['SpecialField']
SpecialField = enum_type_wrapper.EnumTypeWrapper(_SPECIALFIELD)
SFIELD_SCORE = 0


_ALLINDEXESQUERYFIELDPATH = DESCRIPTOR.message_types_by_name['AllIndexesQueryFieldPath']
_QUERYFIELDPATHCOMPONENT = DESCRIPTOR.message_types_by_name['QueryFieldPathComponent']
_QUERYFIELDPATH = DESCRIPTOR.message_types_by_name['QueryFieldPath']
AllIndexesQueryFieldPath = _reflection.GeneratedProtocolMessageType('AllIndexesQueryFieldPath', (_message.Message,), {
  'DESCRIPTOR' : _ALLINDEXESQUERYFIELDPATH,
  '__module__' : 'rockset.query_field_path_pb2'
  # @@protoc_insertion_point(class_scope:rockset.AllIndexesQueryFieldPath)
  })
_sym_db.RegisterMessage(AllIndexesQueryFieldPath)

QueryFieldPathComponent = _reflection.GeneratedProtocolMessageType('QueryFieldPathComponent', (_message.Message,), {
  'DESCRIPTOR' : _QUERYFIELDPATHCOMPONENT,
  '__module__' : 'rockset.query_field_path_pb2'
  # @@protoc_insertion_point(class_scope:rockset.QueryFieldPathComponent)
  })
_sym_db.RegisterMessage(QueryFieldPathComponent)

QueryFieldPath = _reflection.GeneratedProtocolMessageType('QueryFieldPath', (_message.Message,), {
  'DESCRIPTOR' : _QUERYFIELDPATH,
  '__module__' : 'rockset.query_field_path_pb2'
  # @@protoc_insertion_point(class_scope:rockset.QueryFieldPath)
  })
_sym_db.RegisterMessage(QueryFieldPath)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\020io.rockset.protoP\000'
  _SPECIALFIELD._serialized_start=323
  _SPECIALFIELD._serialized_end=355
  _ALLINDEXESQUERYFIELDPATH._serialized_start=43
  _ALLINDEXESQUERYFIELDPATH._serialized_end=69
  _QUERYFIELDPATHCOMPONENT._serialized_start=72
  _QUERYFIELDPATHCOMPONENT._serialized_end=249
  _QUERYFIELDPATH._serialized_start=251
  _QUERYFIELDPATH._serialized_end=321
# @@protoc_insertion_point(module_scope)
