# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rockset/regex.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x13rockset/regex.proto\x12\x07rockset\"e\n\x05Regex\x12\x0f\n\x07pattern\x18\x01 \x01(\t\x12)\n\x08\x65ncoding\x18\x02 \x01(\x0e\x32\x17.rockset.Regex.Encoding\" \n\x08\x45ncoding\x12\x08\n\x04UTF8\x10\x00\x12\n\n\x06LATIN1\x10\x01\x42\x14\n\x10io.rockset.protoP\x00\x62\x06proto3')



_REGEX = DESCRIPTOR.message_types_by_name['Regex']
_REGEX_ENCODING = _REGEX.enum_types_by_name['Encoding']
Regex = _reflection.GeneratedProtocolMessageType('Regex', (_message.Message,), {
  'DESCRIPTOR' : _REGEX,
  '__module__' : 'rockset.regex_pb2'
  # @@protoc_insertion_point(class_scope:rockset.Regex)
  })
_sym_db.RegisterMessage(Regex)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\020io.rockset.protoP\000'
  _REGEX._serialized_start=32
  _REGEX._serialized_end=133
  _REGEX_ENCODING._serialized_start=101
  _REGEX_ENCODING._serialized_end=133
# @@protoc_insertion_point(module_scope)
