# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rockset/document_locator.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1erockset/document_locator.proto\"J\n\x14\x44ocumentLocatorProto\x12\x0e\n\x06raw_id\x18\x01 \x01(\x04\x12\x0f\n\x07indices\x18\x02 \x03(\r\x12\x11\n\tpartition\x18\x03 \x01(\x03\x42\x17\n\x10io.rockset.protoP\x00\xf8\x01\x01\x62\x06proto3')



_DOCUMENTLOCATORPROTO = DESCRIPTOR.message_types_by_name['DocumentLocatorProto']
DocumentLocatorProto = _reflection.GeneratedProtocolMessageType('DocumentLocatorProto', (_message.Message,), {
  'DESCRIPTOR' : _DOCUMENTLOCATORPROTO,
  '__module__' : 'rockset.document_locator_pb2'
  # @@protoc_insertion_point(class_scope:DocumentLocatorProto)
  })
_sym_db.RegisterMessage(DocumentLocatorProto)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\020io.rockset.protoP\000\370\001\001'
  _DOCUMENTLOCATORPROTO._serialized_start=34
  _DOCUMENTLOCATORPROTO._serialized_end=108
# @@protoc_insertion_point(module_scope)
