# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rockset/value.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from rockset import document_locator_pb2 as rockset_dot_document__locator__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x13rockset/value.proto\x12\x07rockset\x1a\x1erockset/document_locator.proto\"\x07\n\x05\x45mpty\"5\n\tDateProto\x12\x0c\n\x04year\x18\x01 \x01(\x03\x12\r\n\x05month\x18\x02 \x01(\x05\x12\x0b\n\x03\x64\x61y\x18\x03 \x01(\x05\"N\n\tTimeProto\x12\x0c\n\x04hour\x18\x01 \x01(\x05\x12\x0e\n\x06minute\x18\x02 \x01(\x05\x12\x0e\n\x06second\x18\x03 \x01(\x05\x12\x13\n\x0bmicrosecond\x18\x04 \x01(\x05\"S\n\rDateTimeProto\x12 \n\x04\x64\x61te\x18\x01 \x01(\x0b\x32\x12.rockset.DateProto\x12 \n\x04time\x18\x02 \x01(\x0b\x32\x12.rockset.TimeProto\":\n\x13GeographyPointProto\x12\x11\n\tlongitude\x18\x01 \x01(\x01\x12\x10\n\x08latitude\x18\x02 \x01(\x01\"H\n\x18GeographyLineStringProto\x12,\n\x06points\x18\x01 \x03(\x0b\x32\x1c.rockset.GeographyPointProto\"I\n\x15GeographyPolygonProto\x12\x30\n\x05loops\x18\x01 \x03(\x0b\x32!.rockset.GeographyLineStringProto\"1\n\x1bGeographyRangeEndpointProto\x12\x12\n\nindex_term\x18\x01 \x01(\t\"\xff\x01\n\x0eGeographyProto\x12-\n\x05point\x18\x01 \x01(\x0b\x32\x1c.rockset.GeographyPointProtoH\x00\x12\x38\n\x0bline_string\x18\x02 \x01(\x0b\x32!.rockset.GeographyLineStringProtoH\x00\x12\x31\n\x07polygon\x18\x03 \x01(\x0b\x32\x1e.rockset.GeographyPolygonProtoH\x00\x12>\n\x0erange_endpoint\x18\x04 \x01(\x0b\x32$.rockset.GeographyRangeEndpointProtoH\x00\x42\x11\n\x0fgeography_union\"%\n\x0bInt128Proto\x12\n\n\x02hi\x18\x01 \x01(\x04\x12\n\n\x02lo\x18\x02 \x01(\x04\"\x86\x0b\n\x05Value\x12\x13\n\tint_value\x18\x01 \x01(\x03H\x00\x12\x15\n\x0b\x66loat_value\x18\x02 \x01(\x01H\x00\x12\x14\n\nbool_value\x18\x03 \x01(\x08H\x00\x12\x16\n\x0cstring_value\x18\x04 \x01(\tH\x00\x12\x15\n\x0b\x62ytes_value\x18\x05 \x01(\x0cH\x00\x12,\n\x0cobject_value\x18\x06 \x01(\x0b\x32\x14.rockset.ObjectValueH\x00\x12*\n\x0b\x61rray_value\x18\x07 \x01(\x0b\x32\x13.rockset.ArrayValueH\x00\x12,\n\x0c\x63ustom_value\x18\x08 \x01(\x0b\x32\x14.rockset.CustomValueH\x00\x12\x14\n\nnull_value\x18\t \x01(\x08H\x00\x12.\n\rlocator_value\x18\n \x01(\x0b\x32\x15.DocumentLocatorProtoH\x00\x12\x19\n\x0ftimestamp_value\x18\x0b \x01(\x03H\x00\x12\x30\n\x0e\x64\x61tetime_value\x18\x0c \x01(\x0b\x32\x16.rockset.DateTimeProtoH\x00\x12(\n\ndate_value\x18\r \x01(\x0b\x32\x12.rockset.DateProtoH\x00\x12(\n\ntime_value\x18\x0e \x01(\x0b\x32\x12.rockset.TimeProtoH\x00\x12\x1e\n\x14month_interval_value\x18\x0f \x01(\x03H\x00\x12$\n\x1amicrosecond_interval_value\x18\x10 \x01(\x03H\x00\x12\x17\n\runknown_value\x18\x11 \x01(\x08H\x00\x12\x32\n\x0fgeography_value\x18\x12 \x01(\x0b\x32\x17.rockset.GeographyProtoH\x00\x12\x31\n\x0fint_array_value\x18\x13 \x01(\x0b\x32\x16.rockset.IntArrayValueH\x00\x12\x35\n\x11\x66loat_array_value\x18\x14 \x01(\x0b\x32\x18.rockset.FloatArrayValueH\x00\x12\x33\n\x10\x62ool_array_value\x18\x15 \x01(\x0b\x32\x17.rockset.BoolArrayValueH\x00\x12\x37\n\x12string_array_value\x18\x16 \x01(\x0b\x32\x19.rockset.StringArrayValueH\x00\x12\x39\n\x13locator_array_value\x18\x17 \x01(\x0b\x32\x1a.rockset.LocatorArrayValueH\x00\x12=\n\x15timestamp_array_value\x18\x18 \x01(\x0b\x32\x1c.rockset.TimestampArrayValueH\x00\x12<\n\x15\x64\x61te_time_array_value\x18\x19 \x01(\x0b\x32\x1b.rockset.DateTimeArrayValueH\x00\x12\x33\n\x10\x64\x61te_array_value\x18\x1a \x01(\x0b\x32\x17.rockset.DateArrayValueH\x00\x12\x33\n\x10time_array_value\x18\x1b \x01(\x0b\x32\x17.rockset.TimeArrayValueH\x00\x12\x46\n\x1amonth_interval_array_value\x18\x1c \x01(\x0b\x32 .rockset.MonthIntervalArrayValueH\x00\x12R\n microsecond_interval_array_value\x18\x1d \x01(\x0b\x32&.rockset.MicrosecondIntervalArrayValueH\x00\x12,\n\x0cint128_value\x18\x1e \x01(\x0b\x32\x14.rockset.Int128ProtoH\x00\x12\x37\n\x12int128_array_value\x18\x1f \x01(\x0b\x32\x19.rockset.Int128ArrayValueH\x00\x42\r\n\x0bvalue_union\",\n\x0b\x43ustomValue\x12\x0c\n\x04type\x18\x01 \x01(\r\x12\x0f\n\x07\x65ncoded\x18\x02 \x01(\x0c\"3\n\x05\x46ield\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x1d\n\x05value\x18\x02 \x01(\x0b\x32\x0e.rockset.Value\"-\n\x0bObjectValue\x12\x1e\n\x06\x66ields\x18\x01 \x03(\x0b\x32\x0e.rockset.Field\"+\n\nArrayValue\x12\x1d\n\x05value\x18\x02 \x03(\x0b\x32\x0e.rockset.Value\"\x1d\n\nNullsValue\x12\x0f\n\x07storage\x18\x01 \x03(\x04\"B\n\rIntArrayValue\x12\r\n\x05value\x18\x01 \x03(\x03\x12\"\n\x05nulls\x18\x02 \x01(\x0b\x32\x13.rockset.NullsValue\"D\n\x0f\x46loatArrayValue\x12\r\n\x05value\x18\x01 \x03(\x01\x12\"\n\x05nulls\x18\x02 \x01(\x0b\x32\x13.rockset.NullsValue\"C\n\x0e\x42oolArrayValue\x12\r\n\x05value\x18\x01 \x03(\x08\x12\"\n\x05nulls\x18\x02 \x01(\x0b\x32\x13.rockset.NullsValue\"<\n\x1aStringArrayValueDictionary\x12\x0f\n\x07offsets\x18\x01 \x03(\r\x12\r\n\x05words\x18\x02 \x01(\x0c\"~\n\x10StringArrayValue\x12\r\n\x05value\x18\x01 \x03(\r\x12\"\n\x05nulls\x18\x02 \x01(\x0b\x32\x13.rockset.NullsValue\x12\x37\n\ndictionary\x18\x03 \x01(\x0b\x32#.rockset.StringArrayValueDictionary\"]\n\x11LocatorArrayValue\x12$\n\x05value\x18\x01 \x03(\x0b\x32\x15.DocumentLocatorProto\x12\"\n\x05nulls\x18\x02 \x01(\x0b\x32\x13.rockset.NullsValue\"H\n\x13TimestampArrayValue\x12\r\n\x05value\x18\x01 \x03(\x03\x12\"\n\x05nulls\x18\x02 \x01(\x0b\x32\x13.rockset.NullsValue\"_\n\x12\x44\x61teTimeArrayValue\x12%\n\x05value\x18\x01 \x03(\x0b\x32\x16.rockset.DateTimeProto\x12\"\n\x05nulls\x18\x02 \x01(\x0b\x32\x13.rockset.NullsValue\"W\n\x0e\x44\x61teArrayValue\x12!\n\x05value\x18\x01 \x03(\x0b\x32\x12.rockset.DateProto\x12\"\n\x05nulls\x18\x02 \x01(\x0b\x32\x13.rockset.NullsValue\"W\n\x0eTimeArrayValue\x12!\n\x05value\x18\x01 \x03(\x0b\x32\x12.rockset.TimeProto\x12\"\n\x05nulls\x18\x02 \x01(\x0b\x32\x13.rockset.NullsValue\"L\n\x17MonthIntervalArrayValue\x12\r\n\x05value\x18\x01 \x03(\x03\x12\"\n\x05nulls\x18\x02 \x01(\x0b\x32\x13.rockset.NullsValue\"R\n\x1dMicrosecondIntervalArrayValue\x12\r\n\x05value\x18\x01 \x03(\x03\x12\"\n\x05nulls\x18\x02 \x01(\x0b\x32\x13.rockset.NullsValue\"[\n\x10Int128ArrayValue\x12#\n\x05value\x18\x01 \x03(\x0b\x32\x14.rockset.Int128Proto\x12\"\n\x05nulls\x18\x02 \x01(\x0b\x32\x13.rockset.NullsValue\"\x8c\x03\n\x04Type\x12(\n\x04type\x18\x01 \x01(\x0e\x32\x18.rockset.Type.ScalarTypeH\x00\x12*\n\x0bobject_type\x18\x02 \x01(\x0b\x32\x13.rockset.ObjectTypeH\x00\x12(\n\narray_type\x18\x03 \x01(\x0b\x32\x12.rockset.ArrayTypeH\x00\x12*\n\x0b\x63ustom_type\x18\x04 \x01(\x0b\x32\x13.rockset.CustomTypeH\x00\x12\x10\n\x08inferred\x18\x05 \x01(\x08\x12%\n\rdefault_value\x18\x06 \x01(\x0b\x32\x0e.rockset.Value\x12#\n\x0csource_field\x18\x07 \x01(\x0b\x32\r.rockset.Type\x12\x0e\n\x06stored\x18\x08 \x01(\x08\x12\x0f\n\x07indexed\x18\t \x01(\x08\"K\n\nScalarType\x12\x08\n\x04NONE\x10\x00\x12\x07\n\x03INT\x10\x01\x12\t\n\x05\x46LOAT\x10\x02\x12\x08\n\x04\x42OOL\x10\x03\x12\n\n\x06STRING\x10\x04\x12\t\n\x05\x42YTES\x10\x05\x42\x0c\n\ntype_union\"3\n\x07KeyType\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x1b\n\x04type\x18\x02 \x01(\x0b\x32\r.rockset.Type\"*\n\nObjectType\x12\x1c\n\x02kt\x18\x01 \x03(\x0b\x32\x10.rockset.KeyType\"(\n\tArrayType\x12\x1b\n\x04type\x18\x01 \x01(\x0b\x32\r.rockset.Type\"\x1a\n\nCustomType\x12\x0c\n\x04type\x18\x01 \x01(\r\"\x1d\n\x0b\x42itSetProto\x12\x0e\n\x06\x62locks\x18\x01 \x03(\x07\x42\x17\n\x10io.rockset.protoP\x00\xf8\x01\x01\x62\x06proto3')



_EMPTY = DESCRIPTOR.message_types_by_name['Empty']
_DATEPROTO = DESCRIPTOR.message_types_by_name['DateProto']
_TIMEPROTO = DESCRIPTOR.message_types_by_name['TimeProto']
_DATETIMEPROTO = DESCRIPTOR.message_types_by_name['DateTimeProto']
_GEOGRAPHYPOINTPROTO = DESCRIPTOR.message_types_by_name['GeographyPointProto']
_GEOGRAPHYLINESTRINGPROTO = DESCRIPTOR.message_types_by_name['GeographyLineStringProto']
_GEOGRAPHYPOLYGONPROTO = DESCRIPTOR.message_types_by_name['GeographyPolygonProto']
_GEOGRAPHYRANGEENDPOINTPROTO = DESCRIPTOR.message_types_by_name['GeographyRangeEndpointProto']
_GEOGRAPHYPROTO = DESCRIPTOR.message_types_by_name['GeographyProto']
_INT128PROTO = DESCRIPTOR.message_types_by_name['Int128Proto']
_VALUE = DESCRIPTOR.message_types_by_name['Value']
_CUSTOMVALUE = DESCRIPTOR.message_types_by_name['CustomValue']
_FIELD = DESCRIPTOR.message_types_by_name['Field']
_OBJECTVALUE = DESCRIPTOR.message_types_by_name['ObjectValue']
_ARRAYVALUE = DESCRIPTOR.message_types_by_name['ArrayValue']
_NULLSVALUE = DESCRIPTOR.message_types_by_name['NullsValue']
_INTARRAYVALUE = DESCRIPTOR.message_types_by_name['IntArrayValue']
_FLOATARRAYVALUE = DESCRIPTOR.message_types_by_name['FloatArrayValue']
_BOOLARRAYVALUE = DESCRIPTOR.message_types_by_name['BoolArrayValue']
_STRINGARRAYVALUEDICTIONARY = DESCRIPTOR.message_types_by_name['StringArrayValueDictionary']
_STRINGARRAYVALUE = DESCRIPTOR.message_types_by_name['StringArrayValue']
_LOCATORARRAYVALUE = DESCRIPTOR.message_types_by_name['LocatorArrayValue']
_TIMESTAMPARRAYVALUE = DESCRIPTOR.message_types_by_name['TimestampArrayValue']
_DATETIMEARRAYVALUE = DESCRIPTOR.message_types_by_name['DateTimeArrayValue']
_DATEARRAYVALUE = DESCRIPTOR.message_types_by_name['DateArrayValue']
_TIMEARRAYVALUE = DESCRIPTOR.message_types_by_name['TimeArrayValue']
_MONTHINTERVALARRAYVALUE = DESCRIPTOR.message_types_by_name['MonthIntervalArrayValue']
_MICROSECONDINTERVALARRAYVALUE = DESCRIPTOR.message_types_by_name['MicrosecondIntervalArrayValue']
_INT128ARRAYVALUE = DESCRIPTOR.message_types_by_name['Int128ArrayValue']
_TYPE = DESCRIPTOR.message_types_by_name['Type']
_KEYTYPE = DESCRIPTOR.message_types_by_name['KeyType']
_OBJECTTYPE = DESCRIPTOR.message_types_by_name['ObjectType']
_ARRAYTYPE = DESCRIPTOR.message_types_by_name['ArrayType']
_CUSTOMTYPE = DESCRIPTOR.message_types_by_name['CustomType']
_BITSETPROTO = DESCRIPTOR.message_types_by_name['BitSetProto']
_TYPE_SCALARTYPE = _TYPE.enum_types_by_name['ScalarType']
Empty = _reflection.GeneratedProtocolMessageType('Empty', (_message.Message,), {
  'DESCRIPTOR' : _EMPTY,
  '__module__' : 'rockset.value_pb2'
  # @@protoc_insertion_point(class_scope:rockset.Empty)
  })
_sym_db.RegisterMessage(Empty)

DateProto = _reflection.GeneratedProtocolMessageType('DateProto', (_message.Message,), {
  'DESCRIPTOR' : _DATEPROTO,
  '__module__' : 'rockset.value_pb2'
  # @@protoc_insertion_point(class_scope:rockset.DateProto)
  })
_sym_db.RegisterMessage(DateProto)

TimeProto = _reflection.GeneratedProtocolMessageType('TimeProto', (_message.Message,), {
  'DESCRIPTOR' : _TIMEPROTO,
  '__module__' : 'rockset.value_pb2'
  # @@protoc_insertion_point(class_scope:rockset.TimeProto)
  })
_sym_db.RegisterMessage(TimeProto)

DateTimeProto = _reflection.GeneratedProtocolMessageType('DateTimeProto', (_message.Message,), {
  'DESCRIPTOR' : _DATETIMEPROTO,
  '__module__' : 'rockset.value_pb2'
  # @@protoc_insertion_point(class_scope:rockset.DateTimeProto)
  })
_sym_db.RegisterMessage(DateTimeProto)

GeographyPointProto = _reflection.GeneratedProtocolMessageType('GeographyPointProto', (_message.Message,), {
  'DESCRIPTOR' : _GEOGRAPHYPOINTPROTO,
  '__module__' : 'rockset.value_pb2'
  # @@protoc_insertion_point(class_scope:rockset.GeographyPointProto)
  })
_sym_db.RegisterMessage(GeographyPointProto)

GeographyLineStringProto = _reflection.GeneratedProtocolMessageType('GeographyLineStringProto', (_message.Message,), {
  'DESCRIPTOR' : _GEOGRAPHYLINESTRINGPROTO,
  '__module__' : 'rockset.value_pb2'
  # @@protoc_insertion_point(class_scope:rockset.GeographyLineStringProto)
  })
_sym_db.RegisterMessage(GeographyLineStringProto)

GeographyPolygonProto = _reflection.GeneratedProtocolMessageType('GeographyPolygonProto', (_message.Message,), {
  'DESCRIPTOR' : _GEOGRAPHYPOLYGONPROTO,
  '__module__' : 'rockset.value_pb2'
  # @@protoc_insertion_point(class_scope:rockset.GeographyPolygonProto)
  })
_sym_db.RegisterMessage(GeographyPolygonProto)

GeographyRangeEndpointProto = _reflection.GeneratedProtocolMessageType('GeographyRangeEndpointProto', (_message.Message,), {
  'DESCRIPTOR' : _GEOGRAPHYRANGEENDPOINTPROTO,
  '__module__' : 'rockset.value_pb2'
  # @@protoc_insertion_point(class_scope:rockset.GeographyRangeEndpointProto)
  })
_sym_db.RegisterMessage(GeographyRangeEndpointProto)

GeographyProto = _reflection.GeneratedProtocolMessageType('GeographyProto', (_message.Message,), {
  'DESCRIPTOR' : _GEOGRAPHYPROTO,
  '__module__' : 'rockset.value_pb2'
  # @@protoc_insertion_point(class_scope:rockset.GeographyProto)
  })
_sym_db.RegisterMessage(GeographyProto)

Int128Proto = _reflection.GeneratedProtocolMessageType('Int128Proto', (_message.Message,), {
  'DESCRIPTOR' : _INT128PROTO,
  '__module__' : 'rockset.value_pb2'
  # @@protoc_insertion_point(class_scope:rockset.Int128Proto)
  })
_sym_db.RegisterMessage(Int128Proto)

Value = _reflection.GeneratedProtocolMessageType('Value', (_message.Message,), {
  'DESCRIPTOR' : _VALUE,
  '__module__' : 'rockset.value_pb2'
  # @@protoc_insertion_point(class_scope:rockset.Value)
  })
_sym_db.RegisterMessage(Value)

CustomValue = _reflection.GeneratedProtocolMessageType('CustomValue', (_message.Message,), {
  'DESCRIPTOR' : _CUSTOMVALUE,
  '__module__' : 'rockset.value_pb2'
  # @@protoc_insertion_point(class_scope:rockset.CustomValue)
  })
_sym_db.RegisterMessage(CustomValue)

Field = _reflection.GeneratedProtocolMessageType('Field', (_message.Message,), {
  'DESCRIPTOR' : _FIELD,
  '__module__' : 'rockset.value_pb2'
  # @@protoc_insertion_point(class_scope:rockset.Field)
  })
_sym_db.RegisterMessage(Field)

ObjectValue = _reflection.GeneratedProtocolMessageType('ObjectValue', (_message.Message,), {
  'DESCRIPTOR' : _OBJECTVALUE,
  '__module__' : 'rockset.value_pb2'
  # @@protoc_insertion_point(class_scope:rockset.ObjectValue)
  })
_sym_db.RegisterMessage(ObjectValue)

ArrayValue = _reflection.GeneratedProtocolMessageType('ArrayValue', (_message.Message,), {
  'DESCRIPTOR' : _ARRAYVALUE,
  '__module__' : 'rockset.value_pb2'
  # @@protoc_insertion_point(class_scope:rockset.ArrayValue)
  })
_sym_db.RegisterMessage(ArrayValue)

NullsValue = _reflection.GeneratedProtocolMessageType('NullsValue', (_message.Message,), {
  'DESCRIPTOR' : _NULLSVALUE,
  '__module__' : 'rockset.value_pb2'
  # @@protoc_insertion_point(class_scope:rockset.NullsValue)
  })
_sym_db.RegisterMessage(NullsValue)

IntArrayValue = _reflection.GeneratedProtocolMessageType('IntArrayValue', (_message.Message,), {
  'DESCRIPTOR' : _INTARRAYVALUE,
  '__module__' : 'rockset.value_pb2'
  # @@protoc_insertion_point(class_scope:rockset.IntArrayValue)
  })
_sym_db.RegisterMessage(IntArrayValue)

FloatArrayValue = _reflection.GeneratedProtocolMessageType('FloatArrayValue', (_message.Message,), {
  'DESCRIPTOR' : _FLOATARRAYVALUE,
  '__module__' : 'rockset.value_pb2'
  # @@protoc_insertion_point(class_scope:rockset.FloatArrayValue)
  })
_sym_db.RegisterMessage(FloatArrayValue)

BoolArrayValue = _reflection.GeneratedProtocolMessageType('BoolArrayValue', (_message.Message,), {
  'DESCRIPTOR' : _BOOLARRAYVALUE,
  '__module__' : 'rockset.value_pb2'
  # @@protoc_insertion_point(class_scope:rockset.BoolArrayValue)
  })
_sym_db.RegisterMessage(BoolArrayValue)

StringArrayValueDictionary = _reflection.GeneratedProtocolMessageType('StringArrayValueDictionary', (_message.Message,), {
  'DESCRIPTOR' : _STRINGARRAYVALUEDICTIONARY,
  '__module__' : 'rockset.value_pb2'
  # @@protoc_insertion_point(class_scope:rockset.StringArrayValueDictionary)
  })
_sym_db.RegisterMessage(StringArrayValueDictionary)

StringArrayValue = _reflection.GeneratedProtocolMessageType('StringArrayValue', (_message.Message,), {
  'DESCRIPTOR' : _STRINGARRAYVALUE,
  '__module__' : 'rockset.value_pb2'
  # @@protoc_insertion_point(class_scope:rockset.StringArrayValue)
  })
_sym_db.RegisterMessage(StringArrayValue)

LocatorArrayValue = _reflection.GeneratedProtocolMessageType('LocatorArrayValue', (_message.Message,), {
  'DESCRIPTOR' : _LOCATORARRAYVALUE,
  '__module__' : 'rockset.value_pb2'
  # @@protoc_insertion_point(class_scope:rockset.LocatorArrayValue)
  })
_sym_db.RegisterMessage(LocatorArrayValue)

TimestampArrayValue = _reflection.GeneratedProtocolMessageType('TimestampArrayValue', (_message.Message,), {
  'DESCRIPTOR' : _TIMESTAMPARRAYVALUE,
  '__module__' : 'rockset.value_pb2'
  # @@protoc_insertion_point(class_scope:rockset.TimestampArrayValue)
  })
_sym_db.RegisterMessage(TimestampArrayValue)

DateTimeArrayValue = _reflection.GeneratedProtocolMessageType('DateTimeArrayValue', (_message.Message,), {
  'DESCRIPTOR' : _DATETIMEARRAYVALUE,
  '__module__' : 'rockset.value_pb2'
  # @@protoc_insertion_point(class_scope:rockset.DateTimeArrayValue)
  })
_sym_db.RegisterMessage(DateTimeArrayValue)

DateArrayValue = _reflection.GeneratedProtocolMessageType('DateArrayValue', (_message.Message,), {
  'DESCRIPTOR' : _DATEARRAYVALUE,
  '__module__' : 'rockset.value_pb2'
  # @@protoc_insertion_point(class_scope:rockset.DateArrayValue)
  })
_sym_db.RegisterMessage(DateArrayValue)

TimeArrayValue = _reflection.GeneratedProtocolMessageType('TimeArrayValue', (_message.Message,), {
  'DESCRIPTOR' : _TIMEARRAYVALUE,
  '__module__' : 'rockset.value_pb2'
  # @@protoc_insertion_point(class_scope:rockset.TimeArrayValue)
  })
_sym_db.RegisterMessage(TimeArrayValue)

MonthIntervalArrayValue = _reflection.GeneratedProtocolMessageType('MonthIntervalArrayValue', (_message.Message,), {
  'DESCRIPTOR' : _MONTHINTERVALARRAYVALUE,
  '__module__' : 'rockset.value_pb2'
  # @@protoc_insertion_point(class_scope:rockset.MonthIntervalArrayValue)
  })
_sym_db.RegisterMessage(MonthIntervalArrayValue)

MicrosecondIntervalArrayValue = _reflection.GeneratedProtocolMessageType('MicrosecondIntervalArrayValue', (_message.Message,), {
  'DESCRIPTOR' : _MICROSECONDINTERVALARRAYVALUE,
  '__module__' : 'rockset.value_pb2'
  # @@protoc_insertion_point(class_scope:rockset.MicrosecondIntervalArrayValue)
  })
_sym_db.RegisterMessage(MicrosecondIntervalArrayValue)

Int128ArrayValue = _reflection.GeneratedProtocolMessageType('Int128ArrayValue', (_message.Message,), {
  'DESCRIPTOR' : _INT128ARRAYVALUE,
  '__module__' : 'rockset.value_pb2'
  # @@protoc_insertion_point(class_scope:rockset.Int128ArrayValue)
  })
_sym_db.RegisterMessage(Int128ArrayValue)

Type = _reflection.GeneratedProtocolMessageType('Type', (_message.Message,), {
  'DESCRIPTOR' : _TYPE,
  '__module__' : 'rockset.value_pb2'
  # @@protoc_insertion_point(class_scope:rockset.Type)
  })
_sym_db.RegisterMessage(Type)

KeyType = _reflection.GeneratedProtocolMessageType('KeyType', (_message.Message,), {
  'DESCRIPTOR' : _KEYTYPE,
  '__module__' : 'rockset.value_pb2'
  # @@protoc_insertion_point(class_scope:rockset.KeyType)
  })
_sym_db.RegisterMessage(KeyType)

ObjectType = _reflection.GeneratedProtocolMessageType('ObjectType', (_message.Message,), {
  'DESCRIPTOR' : _OBJECTTYPE,
  '__module__' : 'rockset.value_pb2'
  # @@protoc_insertion_point(class_scope:rockset.ObjectType)
  })
_sym_db.RegisterMessage(ObjectType)

ArrayType = _reflection.GeneratedProtocolMessageType('ArrayType', (_message.Message,), {
  'DESCRIPTOR' : _ARRAYTYPE,
  '__module__' : 'rockset.value_pb2'
  # @@protoc_insertion_point(class_scope:rockset.ArrayType)
  })
_sym_db.RegisterMessage(ArrayType)

CustomType = _reflection.GeneratedProtocolMessageType('CustomType', (_message.Message,), {
  'DESCRIPTOR' : _CUSTOMTYPE,
  '__module__' : 'rockset.value_pb2'
  # @@protoc_insertion_point(class_scope:rockset.CustomType)
  })
_sym_db.RegisterMessage(CustomType)

BitSetProto = _reflection.GeneratedProtocolMessageType('BitSetProto', (_message.Message,), {
  'DESCRIPTOR' : _BITSETPROTO,
  '__module__' : 'rockset.value_pb2'
  # @@protoc_insertion_point(class_scope:rockset.BitSetProto)
  })
_sym_db.RegisterMessage(BitSetProto)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\020io.rockset.protoP\000\370\001\001'
  _EMPTY._serialized_start=64
  _EMPTY._serialized_end=71
  _DATEPROTO._serialized_start=73
  _DATEPROTO._serialized_end=126
  _TIMEPROTO._serialized_start=128
  _TIMEPROTO._serialized_end=206
  _DATETIMEPROTO._serialized_start=208
  _DATETIMEPROTO._serialized_end=291
  _GEOGRAPHYPOINTPROTO._serialized_start=293
  _GEOGRAPHYPOINTPROTO._serialized_end=351
  _GEOGRAPHYLINESTRINGPROTO._serialized_start=353
  _GEOGRAPHYLINESTRINGPROTO._serialized_end=425
  _GEOGRAPHYPOLYGONPROTO._serialized_start=427
  _GEOGRAPHYPOLYGONPROTO._serialized_end=500
  _GEOGRAPHYRANGEENDPOINTPROTO._serialized_start=502
  _GEOGRAPHYRANGEENDPOINTPROTO._serialized_end=551
  _GEOGRAPHYPROTO._serialized_start=554
  _GEOGRAPHYPROTO._serialized_end=809
  _INT128PROTO._serialized_start=811
  _INT128PROTO._serialized_end=848
  _VALUE._serialized_start=851
  _VALUE._serialized_end=2265
  _CUSTOMVALUE._serialized_start=2267
  _CUSTOMVALUE._serialized_end=2311
  _FIELD._serialized_start=2313
  _FIELD._serialized_end=2364
  _OBJECTVALUE._serialized_start=2366
  _OBJECTVALUE._serialized_end=2411
  _ARRAYVALUE._serialized_start=2413
  _ARRAYVALUE._serialized_end=2456
  _NULLSVALUE._serialized_start=2458
  _NULLSVALUE._serialized_end=2487
  _INTARRAYVALUE._serialized_start=2489
  _INTARRAYVALUE._serialized_end=2555
  _FLOATARRAYVALUE._serialized_start=2557
  _FLOATARRAYVALUE._serialized_end=2625
  _BOOLARRAYVALUE._serialized_start=2627
  _BOOLARRAYVALUE._serialized_end=2694
  _STRINGARRAYVALUEDICTIONARY._serialized_start=2696
  _STRINGARRAYVALUEDICTIONARY._serialized_end=2756
  _STRINGARRAYVALUE._serialized_start=2758
  _STRINGARRAYVALUE._serialized_end=2884
  _LOCATORARRAYVALUE._serialized_start=2886
  _LOCATORARRAYVALUE._serialized_end=2979
  _TIMESTAMPARRAYVALUE._serialized_start=2981
  _TIMESTAMPARRAYVALUE._serialized_end=3053
  _DATETIMEARRAYVALUE._serialized_start=3055
  _DATETIMEARRAYVALUE._serialized_end=3150
  _DATEARRAYVALUE._serialized_start=3152
  _DATEARRAYVALUE._serialized_end=3239
  _TIMEARRAYVALUE._serialized_start=3241
  _TIMEARRAYVALUE._serialized_end=3328
  _MONTHINTERVALARRAYVALUE._serialized_start=3330
  _MONTHINTERVALARRAYVALUE._serialized_end=3406
  _MICROSECONDINTERVALARRAYVALUE._serialized_start=3408
  _MICROSECONDINTERVALARRAYVALUE._serialized_end=3490
  _INT128ARRAYVALUE._serialized_start=3492
  _INT128ARRAYVALUE._serialized_end=3583
  _TYPE._serialized_start=3586
  _TYPE._serialized_end=3982
  _TYPE_SCALARTYPE._serialized_start=3893
  _TYPE_SCALARTYPE._serialized_end=3968
  _KEYTYPE._serialized_start=3984
  _KEYTYPE._serialized_end=4035
  _OBJECTTYPE._serialized_start=4037
  _OBJECTTYPE._serialized_end=4079
  _ARRAYTYPE._serialized_start=4081
  _ARRAYTYPE._serialized_end=4121
  _CUSTOMTYPE._serialized_start=4123
  _CUSTOMTYPE._serialized_end=4149
  _BITSETPROTO._serialized_start=4151
  _BITSETPROTO._serialized_end=4180
# @@protoc_insertion_point(module_scope)
